<?php
require('../../../wp-blog-header.php');

set_time_limit(200);
function return_300($seconds) {
    // change the default feed cache recreation period to 2 hours
    return 300;
}

add_filter('wp_feed_cache_transient_lifetime', 'return_300');

$campaignId = arSelectCampaign();
if (empty($campaignId)) {
  echo "No Campaign";
  exit;
}
$feed = arSelectFeed($campaignId);

if (empty($feed)) {
  echo "No feed";
  exit;
}
arPost($campaignId, $feed);

echo '--- The End ---';

function arSelectCampaign() {
    global $wpdb;
    $wpdb->show_errors();

    $table_name = $wpdb->prefix . "arp_campaigns";

    $query = "SELECT id FROM $table_name where name != '' ORDER BY RAND() limit 1";
    $id = $wpdb->get_var($query);
    return $id;
}

function arSelectFeed($campaignId) {
    global $wpdb;
    $wpdb->show_errors();

    $table_name = $wpdb->prefix . "arp_feeds";

    $query = "SELECT website FROM $table_name where campaign_id = ${campaignId} ORDER BY RAND() limit 1";
    $url = $wpdb->get_var($query);
    return $url;
}

function arPost($campaignId, $feed) {
    $ar_wordai_auto = get_post_meta('111111119', $campaignId . 'ar_wordai_auto', true);

    if (arChooseToPost(5)) {
        global $wpdb;
        $wpdb->show_errors();
        if (!empty($feed)) {
            $rss = fetch_feed($feed);

            if (!is_wp_error($rss)) {
                $maxitems = $rss->get_item_quantity(0);
                $rss_items = $rss->get_items(0, $maxitems);

                foreach ($rss_items as $item) {
                    $link = $item->get_permalink();
                    $content = $item->get_content();
                    $title = $item->get_title();

                    // $imgURL = arGetImgSrc($content);

                    $inhistory = arCheckHistory($title, $campaignId);

                    if ($inhistory == 0) {
                        $cwis = arUpdateContentWithImageSettings($content, $campaignId);
                        $imgURL = $cwis[1];
                        $content = $cwis[0];

                        if ($ar_wordai_auto == 'yes') {
                          $spintax = new arSpintax();
                          $content = $spintax->process(ar_wordai_api($content, $campaignId));
                        }
                        if (empty($content)) continue;

                        $postid = arPostToBlog($imgURL, $content, $title, $link, $campaignId);
                        arInsertHistory($link, '', '', $title, $campaignId);

                        $permalink = get_permalink($postid);
                        return;
                    }
                }
            }
        } else {
            // $error = $rss->get_error_message();
            // var_dump($rss);
            echo "Error over here";
        }
    }
}

function arGetImgSrc($content) {
    $matches = array();
    $match = preg_match('/\bhttps?:\/\/\S+(?:png|jpe?g)\b/i', $content, $matches);

    if ($match == 1) {
        return $matches[0];
    } else {
        return "";
    }
}

function arUpdateContentWithImageSettings($content, $campaignId) {
  $ar_image_replace         = get_post_meta('111111119', $campaignId . 'ar_image_replace', true);
  $ar_image_first_featured  = get_post_meta('111111119', $campaignId . 'ar_image_first_featured', true);
  $ar_image_first_remove    = get_post_meta('111111119', $campaignId . 'ar_image_first_remove', true);
  $ar_image_all_remove      = get_post_meta('111111119', $campaignId . 'ar_image_all_remove', true);

  $first_image = "";
  if ($ar_image_first_featured === 'yes') {
    $first_image = arGetImgSrc($content);
  }

  if ($ar_image_first_remove === 'yes') {
    $content = preg_replace('/<img\s+[^>]*?\/>/i', '', $content, 1);
    $content = preg_replace('/<\/img>/i', '', $content, 1);
  }

  if ($ar_image_all_remove === 'yes') {
    $content = preg_replace('/(<img\s+[^>]*?\/>)/i', '', $content);
    $content = preg_replace('/(<\/img>)/i', '', $content);
  }

  if ($ar_image_replace === 'yes') {
    if (($ar_image_first_featured === 'yes') && ($ar_image_first_remove === 'yes')) {
      $first_image = arPopImage($first_image, $campaignId);
    }

    $match = preg_match('/\bhttps?:\/\/\S+(?:png|jpe?g)\b/i', $content, $matches);
    foreach ($matches as $idx => $match) {
      $content = str_replace($match, arPopImage($match, $campaignId), $content);
    }
  }

  return [$content, $first_image];
}

function arPopImage($img, $campaignId) {
  global $wpdb;
  $wpdb->show_errors();
  $table_name = $wpdb->prefix . "arp_images";

  $query = "SELECT * FROM $table_name where campaign_id=${campaignId} order by rand() limit 1";
  $result  = $wpdb->get_row($query);

  if (empty($result)) return $img;

  $wpdb->delete($table_name, array('id' => $result->id));
  return $result->url;
}

function arChooseToPost($frequency) {
  if ($frequency == 1) {
    $frequency = 0;
  }
  $random = mt_rand(1, 40);
  $powered = pow($frequency, 2);

  if ($random <= $powered+1) {
    return 1;
  } else {
    return 0;
  }
}

function arInsertHistory($source, $code, $link, $title, $campaignId) {
    global $wpdb;
    $wpdb->show_errors();
    $table_name = $wpdb->prefix . "arp_history";

    $result = $wpdb->insert($table_name, array(
        'campaign_id' => $campaignId,
        'source' => $source,
        'comment' => $title,
        'timesent'=> time(),
        'error'=> $code,
    ));
}

function arCheckHistory($title, $campaignId) {
    global $wpdb;
    $wpdb->show_errors();

    $title = html_entity_decode($title);
    $table_name = $wpdb->prefix . "arp_history";

    $title = addslashes($title);

    $query = "SELECT * FROM $table_name WHERE campaign_id=${campaignId} and Comment='$title'";
    $result  = $wpdb->get_row($query);

    if ($result == null) {
        return 0;
    } else {
        return 1;
    }
}

function arPostToBlog($img, $content, $title, $link, $campaignId) {
    $ar_showsource = get_post_meta('111111119', $campaignId . 'ar_showsource', true);
    $ar_sourcelabel = get_post_meta('111111119', $campaignId . 'ar_sourcelabel', true);
    $ar_category = get_post_meta('111111119', $campaignId . 'ar_category', true);
    $ar_postlength = get_post_meta('111111119', $campaignId . 'ar_postlength', true);
    $ar_intro = get_post_meta('111111119', $campaignId . 'ar_intro', true);
    $ar_outro = get_post_meta('111111119', $campaignId . 'ar_outro', true);
    $ar_draft = get_post_meta('111111119', $campaignId . 'ar_draft', true);

    if (empty($ar_category)) {
        $ar_category = "Uncategorized";
    }
    $catid = get_cat_ID($ar_category);

    if (!empty($ar_postlength)) {
        $content = strip_tags($content, '<br><p><img>');
        $content =  substr($content, 0, $ar_postlength);
        $content = $content."... <a href ='".$link."'>Read More</a>";
    }

    $spintax = new arSpintax();
    $ar_intro= $spintax->process($ar_intro);
    $ar_outro= $spintax->process($ar_outro);

    $content= "<p>" . $ar_intro . "</p><p>" . $content;
    $content = $content . "</p><p>" . $ar_outro;

    if ($ar_showsource == "yes") {
        $content = $ar_sourcelabel." <a href ='".$link."'>".$link."</a> ".$content."<br />";
    }

    if ($ar_draft == "yes") {
        $status = "draft";
    } else {
        $status = "publish";
    }

    $my_post = array(
      'post_title'    => $title,
      'post_content'  => $content,
      'post_excerpt'  => $content,
      'post_status'   => $status,
      'post_author'   => 1,
      'post_category' => array($catid)
    );

    global $allowedposttags;
    $allowedposttags['div'] = array('align' => array(), 'class' => array(), 'id' => array(), 'dir' => array(), 'lang' => array(), 'style' => array(), 'xml:lang' => array() );
    $allowedposttags['iframe'] = array('src' => array() );
    $post_id = wp_insert_post($my_post, $wp_error);

    if (!empty($img)) {
      arUploadImage($post_id, $img, $title);
    }

    return $post_id;
}

function arUploadImage($post_id, $url, $title) {
    require_once(ABSPATH . "wp-admin" . '/includes/image.php');
    require_once(ABSPATH . "wp-admin" . '/includes/file.php');
    require_once(ABSPATH . "wp-admin" . '/includes/media.php');

    $tmp_name = download_url($url);
    $file_array['name'] = $post_id. '-thumb.jpg';  // new filename based on slug
    $file_array['tmp_name'] = $tmp_name;

    // If error storing temporarily, unlink
    if (is_wp_error($tmp_name)) {
        @unlink($file_array['tmp_name']);
        $file_array['tmp_name'] = '';
    }

    // do validation and storage .  Make a description based on the Post_ID
    $attachment_id = media_handle_sideload($file_array, $post_id, 'Thumbnail for ' .$post_id);

    // If error storing permanently, unlink
    if (is_wp_error($attachment_id)) {
        $error_string = $attachment_id->get_error_message();
        @unlink($file_array['tmp_name']);
        return;
    }

    // Set as the post attachment
    $post_result= add_post_meta($post_id, '_thumbnail_id', $attachment_id, true);
    $src = wp_get_attachment_url($attachment_id);

    return $src;
}

function arRemoveImage($content) {
    $content = preg_replace('/<img.+src=[\'"](?P<src>.+?)[\'"].*>/i', '', $content);
    return $content;
}
